@@ -131,6 +131,11 @@ private Q_SLOTS:
      */
     void pasteSelection();
 
+    /**
+     * Insert contents of selected file into the currently open file
+     */
+    void pasteFromFile();
+
     /**
      * Copy current selected stuff and paste previous content of clipboard as one operation.
      */
@@ -543,7 +548,7 @@ public:
 
     bool isLineRTL(int line) const;
 
-    QTextLayout *textLayout(const KTextEditor::Cursor pos) const;
+    const QTextLayout *textLayout(const KTextEditor::Cursor pos) const;
 
 public Q_SLOTS:
     void indent();
@@ -985,9 +990,6 @@ public:
 public:
     KTextEditor::Range visibleRange();
 
-Q_SIGNALS:
-    void displayRangeChanged(KTextEditor::ViewPrivate *view);
-
 protected:
     bool event(QEvent *e) override;
 
@@ -1049,7 +1051,7 @@ public:
      * @param lineRange line range that the change spans
      * @param needsRepaint do we need to trigger repaints? e.g. if ranges with attributes change
      */
-    void notifyAboutRangeChange(KTextEditor::LineRange lineRange, bool needsRepaint);
+    void notifyAboutRangeChange(KTextEditor::LineRange lineRange, bool needsRepaint, Kate::TextRange *deleteRange);
 
 private Q_SLOTS:
     /**
